@@ -51,7 +51,7 @@ def getImgs(status):
 	if not status:
 		return []
 	# seems video is not returned in side the json, there is nothing we can do...
-	return [x['media_url'] for x in getEntities(status).get('media', [])
+	return [x['media_url'] + '?name=large' for x in getEntities(status).get('media', [])
 		if x['type'] == 'photo']
 
 def getVideo(status):
@@ -85,7 +85,7 @@ def getQuote(status, func):
 	return result
 
 def getInReplyToLink(status):
-	if status.in_reply_to_screen_name:
+	if status.in_reply_to_screen_name and status.in_reply_to_status_id:
 		return ' [origin](https://twitter.com/%s/status/%d)' % (status.in_reply_to_screen_name, status.in_reply_to_status_id)
 	return ''
 
